@@ -17,7 +17,7 @@ package PostScript::Report::Builder;
 # ABSTRACT: Build a PostScript::Report object
 #---------------------------------------------------------------------
 
-our $VERSION = '0.03';
+our $VERSION = '0.07';
 
 use 5.008;
 use Moose;
@@ -109,12 +109,20 @@ sub build
   $self->create_fonts( $rpt, $desc{fonts} );
 
   # Set the report's default fonts:
-  foreach my $type (qw(font label_font)) {
+  foreach my $type (qw(font)) {
     next unless exists $desc{$type};
 
     $rpt->$type( $self->get_font( $desc{$type} ) );
   }
 
+  # Set any extra fonts:
+  if (my $extra = $rpt->extra_styles) {
+    foreach my $type (keys %$extra) {
+      $extra->{$type} = $self->get_font( $extra->{$type} )
+          if $type =~ /(?:^|_)font$/;
+    } # end foreach key
+  } # end if extra_styles
+
   # Prepare the columns:
   $self->create_columns(\%desc) if $desc{columns};
 
@@ -143,6 +151,20 @@ sub get_report_parameters
     $param{$key} = $desc->{$key} if exists $desc->{$key};
   }
 
+  # Move any extra attributes to extra_styles:
+  my %valid = (
+     (map { $_ => 1 } qw(columns fonts stripe_page stripe)),
+     (map { my $arg = $_->init_arg;
+                    ((defined $arg ? $arg : $_->name) => 1) }
+       $self->meta->get_all_attributes,
+       $self->report_class->meta->get_all_attributes)
+  );
+
+  while (my $key = each %$desc) {
+    $param{extra_styles}{$key} = $self->_extra_value($key, $desc->{$key})
+        unless $valid{$key};
+  } # end while each entry in %param
+
   # See if we're using zebra striping:
   my ($use_param, @colors) = 0;
   my $stripe_type;
@@ -284,9 +306,10 @@ sub build_box
     $boxType  = $desc->[0];
     %param = %{ $desc->[1] };
     $defaultClass = delete $param{_default} if exists $param{_default};
-    $self->_fixup_parms(\%param);
     $start = 2;
   }
+  my $class = $self->get_class($boxType);
+  $self->_fixup_parms(\%param, $class);
 
   my @children = map {
     ref $_ eq 'HASH'
@@ -296,7 +319,7 @@ sub build_box
   } @$desc[$start .. $#$desc];
 
   # Construct the box:
-  $self->get_class($boxType)->new(children => \@children, %param);
+  $class->new(children => \@children, %param);
 } # end build_box
 
 #---------------------------------------------------------------------
@@ -308,9 +331,8 @@ sub build_object
 
   $class = $self->get_class(delete($parms{_class}) || $class, $prefix);
 
-  $self->_fixup_parms(\%parms);
+  $self->_fixup_parms(\%parms, $class);
 
-  $self->require_class($class);
   $class->new(\%parms);
 } # end build_object
 
@@ -330,7 +352,15 @@ sub get_class
 #---------------------------------------------------------------------
 sub _fixup_parms
 {
-  my ($self, $parms) = @_;
+  my ($self, $parms, $class) = @_;
+
+  $self->require_class($class);
+
+  my %valid = map { my $arg = $_->init_arg;
+                    defined $arg ? ($arg => 1) : () }
+      $class->meta->get_all_attributes;
+
+  my $extra = $parms->{extra_styles};
 
   while (my ($key, $val) = each %$parms) {
     if ($key =~ /(?:^|_)font$/) {
@@ -346,9 +376,30 @@ sub _fixup_parms
                                              'PostScript::Report::Value::');
       }
     } # end elsif key 'value' and ref $val
+
+    # Move non-standard attributes to extra_styles:
+    $extra->{$key} = $self->_extra_value($key, delete $parms->{$key})
+        unless $valid{$key};
   } # end while each ($key, $val) in %$parms
+
+  $parms->{extra_styles} = $extra if $extra;
 } # end _fixup_parms
 
+#---------------------------------------------------------------------
+# Coerce a value for the extra_styles hash:
+
+sub _extra_value
+{
+  my ($self, $key, $val) = @_;
+
+  if ($key =~ /(?:^|_)color$/) {
+    defined(my $color = to_Color($val)) or die "Invalid $key $val";
+    return $color;
+  }
+
+  return $val;
+} # end _extra_value
+
 #---------------------------------------------------------------------
 sub require_class
 {
@@ -377,9 +428,9 @@ PostScript::Report::Builder - Build a PostScript::Report object
 
 =head1 VERSION
 
-This document describes version 0.03 of
-PostScript::Report::Builder, released March 26, 2010
-as part of PostScript-Report version 0.06.
+This document describes version 0.07 of
+PostScript::Report::Builder, released June 19, 2010
+as part of PostScript-Report version 0.07.
 
 =head1 SYNOPSIS
 
@@ -630,10 +681,10 @@ No bugs have been reported.
 
 =head1 AUTHOR
 
-Christopher J. Madsen  C<< <perlATcjmweb.net> >>
+Christopher J. Madsen  S<C<< <perl AT cjmweb.net> >>>
 
 Please report any bugs or feature requests to
-C<< <bug-PostScript-ReportATrt.cpan.org> >>,
+S<C<< <bug-PostScript-Report AT rt.cpan.org> >>>,
 or through the web interface at
 L<http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-Report>
 
