@@ -229,8 +229,8 @@ PostScript::Report::Image - Include an EPS file
 =head1 VERSION
 
 This document describes version 0.06 of
-PostScript::Report::Image, released March 26, 2010
-as part of PostScript-Report version 0.06.
+PostScript::Report::Image, released June 19, 2010
+as part of PostScript-Report version 0.07.
 
 =head1 DESCRIPTION
 
@@ -290,10 +290,10 @@ significantly increase the file size.
 
 =head1 AUTHOR
 
-Christopher J. Madsen  C<< <perlATcjmweb.net> >>
+Christopher J. Madsen  S<C<< <perl AT cjmweb.net> >>>
 
 Please report any bugs or feature requests to
-C<< <bug-PostScript-ReportATrt.cpan.org> >>,
+S<C<< <bug-PostScript-Report AT rt.cpan.org> >>>,
 or through the web interface at
 L<http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-Report>
 
