@@ -49,8 +49,8 @@ PostScript::Report::Role::Value - Something that returns a field value
 =head1 VERSION
 
 This document describes version 0.01 of
-PostScript::Report::Role::Value, released March 26, 2010
-as part of PostScript-Report version 0.06.
+PostScript::Report::Role::Value, released June 19, 2010
+as part of PostScript-Report version 0.07.
 
 =head1 DESCRIPTION
 
@@ -91,10 +91,10 @@ No bugs have been reported.
 
 =head1 AUTHOR
 
-Christopher J. Madsen  C<< <perlATcjmweb.net> >>
+Christopher J. Madsen  S<C<< <perl AT cjmweb.net> >>>
 
 Please report any bugs or feature requests to
-C<< <bug-PostScript-ReportATrt.cpan.org> >>,
+S<C<< <bug-PostScript-Report AT rt.cpan.org> >>>,
 or through the web interface at
 L<http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-Report>
 
