@@ -118,8 +118,8 @@ PostScript::Report::Types - type library for PostScript::Report
 =head1 VERSION
 
 This document describes version 0.06 of
-PostScript::Report::Types, released March 26, 2010
-as part of PostScript-Report version 0.06.
+PostScript::Report::Types, released June 19, 2010
+as part of PostScript-Report version 0.07.
 
 =head1 DESCRIPTION
 
@@ -184,10 +184,10 @@ L<MooseX::Types>, L<MooseX::Types::Moose>.
 
 =head1 AUTHOR
 
-Christopher J. Madsen  C<< <perlATcjmweb.net> >>
+Christopher J. Madsen  S<C<< <perl AT cjmweb.net> >>>
 
 Please report any bugs or feature requests to
-C<< <bug-PostScript-ReportATrt.cpan.org> >>,
+S<C<< <bug-PostScript-Report AT rt.cpan.org> >>>,
 or through the web interface at
 L<http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-Report>
 
